==> openshift-model-operator-6.2.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/OAuthAPIServerStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OAuthAPIServerStatusFluentImpl<A extends OAuthAPIServerStatusFluent<A>> extends BaseFluent<A> implements OAuthAPIServerStatusFluent<A>{
  public OAuthAPIServerStatusFluentImpl() {
  }
  public OAuthAPIServerStatusFluentImpl(OAuthAPIServerStatus instance) {
    this.withLatestAvailableRevision(instance.getLatestAvailableRevision()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Integer latestAvailableRevision;
  private Map<String,Object> additionalProperties;
  public Integer getLatestAvailableRevision() {
    return this.latestAvailableRevision;
  }
  public A withLatestAvailableRevision(Integer latestAvailableRevision) {
    this.latestAvailableRevision=latestAvailableRevision; return (A) this;
  }
  public Boolean hasLatestAvailableRevision() {
    return this.latestAvailableRevision != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OAuthAPIServerStatusFluentImpl that = (OAuthAPIServerStatusFluentImpl) o;
    if (latestAvailableRevision != null ? !latestAvailableRevision.equals(that.latestAvailableRevision) :that.latestAvailableRevision != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(latestAvailableRevision,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (latestAvailableRevision != null) { sb.append("latestAvailableRevision:"); sb.append(latestAvailableRevision + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/OAuthAPIServerStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OAuthAPIServerStatusFluentImpl<A extends OAuthAPIServerStatusFluent<A>> extends BaseFluent<A> implements OAuthAPIServerStatusFluent<A>{
  public OAuthAPIServerStatusFluentImpl() {
  }
  public OAuthAPIServerStatusFluentImpl(OAuthAPIServerStatus instance) {
    if (instance != null) {
      this.withLatestAvailableRevision(instance.getLatestAvailableRevision());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Integer latestAvailableRevision;
  private Map<String,Object> additionalProperties;
  public Integer getLatestAvailableRevision() {
    return this.latestAvailableRevision;
  }
  public A withLatestAvailableRevision(Integer latestAvailableRevision) {
    this.latestAvailableRevision=latestAvailableRevision; return (A) this;
  }
  public Boolean hasLatestAvailableRevision() {
    return this.latestAvailableRevision != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OAuthAPIServerStatusFluentImpl that = (OAuthAPIServerStatusFluentImpl) o;
    if (!java.util.Objects.equals(latestAvailableRevision, that.latestAvailableRevision)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(latestAvailableRevision,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (latestAvailableRevision != null) { sb.append("latestAvailableRevision:"); sb.append(latestAvailableRevision + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
